Learn R Programming

rbi (version 0.7.0)

Extract.bi_model: Subset and replace model lines

Description

Extracts a subset of lines from the model and, if used with the assignment operator, assigns new character strings.

Usage

# S3 method for bi_model
[(x, i, ...) <- value

Arguments

x

A bi_model

i

A vector of line numbers

...

ignored

value

A vector of the same length as i, containing the replacement strings

Examples

Run this code
# NOT RUN {
model_file_name <- system.file(package="rbi", "PZ.bi")
PZ <- bi_model(filename = model_file_name)
PZ[3:4]
PZ[3:4] <- c("const e = 0.4", "const m_l = 0.05")
# }

Run the code above in your browser using DataLab