Learn R Programming

rbi (version 0.6.0)

`[<-`: Subset assignment to mode lines

Description

Assigns new character strings a subset of lines from the model

Usage

"["(x, i) <- value

Arguments

x
A bi_model
i
A vector of line numbers
value
A vector of the same length as i, containing the replacement strings

Examples

Run this code
model_file_name <- system.file(package="rbi", "PZ.bi")
PZ <- bi_model(filename = model_file_name)
PZ[3:4] <- c("const e = 0.4", "const m_l = 0.05")

Run the code above in your browser using DataLab