Learn R Programming

rbi (version 0.7.0)

add_output: Add output file to a libbi object

Description

Adds an output file to a libbi object. This is useful to recreate a libbi object from the model and output files of a previous run

Usage

# S3 method for libbi
add_output(x, output, ...)

Arguments

x

a libbi object

output

name of the file to add as output file, or a list of data frames that contain the outputs

...

ignored

Examples

Run this code
# NOT RUN {
bi <- libbi(model = system.file(package="rbi", "PZ.bi"))
example_output_file <- system.file(package="rbi", "example_output.nc")
bi <- add_output(bi, example_output_file)
# }

Run the code above in your browser using DataLab