assert_files: Check that a LibBi wrapper has valid output
Description
This checks that the libbi object given has been run (via sample, filter or optimize)) and the output file has not been modified since.
Usage
# S3 method for libbi
assert_files(x, ...)
Value
nothing (invisible NULL); an error will be thrown if there is a problem
Arguments
- x
a libbi object
- ...
ignored