Learn R Programming

rbi (version 0.9.1)

assert_output: Check that a LibBi wrapper has valid output

Description

This checks that the libbi object given has been run (via sample, filter or optimize)) and the output file has not been modified since.

Usage

# S3 method for libbi
assert_output(x, ...)

Arguments

x

a libbi object

...

ignored