Learn R Programming

rbi (version 0.10.4)

attach_file: Deprecated (use 'attach' instead). Attach a new file or data set to a libbi object

Description

Deprecated (use 'attach' instead). Adds an (output, obs, etc.) file to a libbi object. This is useful to recreate a libbi object from the model and output files of a previous run

Usage

# S3 method for libbi
attach_file(x, file, data, force = FALSE, ...)

Value

an updated libbi object

Arguments

x

a libbi object

file

the type of the file to attach, one of "output", "obs", "input" or "init"

data

name of the file to attach, or a list of data frames that contain the outputs

force

attach the file even if one like this already exists in the libbi object

...

any options to bi_write (e.g., 'time_dim')