powered by
This function gets the name of all the variables in the passed file, list or libbi object
libbi
bi_contents(read)
either a path to a NetCDF file, or a NetCDF connection created using nc_open, or a libbi object from which to read the output
nc_open
vector of variable names
# NOT RUN { example_output_file <- system.file(package="rbi", "example_output.nc") bi_contents(example_output_file) # }
Run the code above in your browser using DataLab