bi_model creates a model object for Rbi from a libbi file, URL or character vector.
Once the instance is created, the model can be fed to a libbi object.
Usage
bi_model(filename, lines, ...)
Arguments
filename
the file name of the model file
lines
lines of the model (if no filename is given), a character vector