bi_model_fix: Fix noise term, state or parameter of a libbi model
Description
Replaces all variables with fixed values as given in 'fixed'; note that this will not replace differential equations and lead to an error if applied to states that are changed inside an "ode" block