Learn R Programming

rbi (version 0.7.0)

extract_sample: Extract a sample from a LibBi run.

Description

This function takes the provided libbi object which has been run and extracts a data frame. traces.

Usage

extract_sample(x, np, ...)

Arguments

x

a libbi object which has been run, or a list of data frames containing parameter traces (as returned by from bi_read); if it is not a libbi object, either 'all' must be TRUE or a model given

np

iteration to extract; if not given a random sample will be extracted

...

parameters to bi_read (e.g., dimensions)

Value

list of parameters and trajectories