The method filter launches libbi to filter state trajectories. See the options to run.libbi for how to specify the various components of sampling with LibBi, and the LibBi manual for all options that can be passed when the client is filter.
If x is given as a 'bi_model', a libbi object will be created from the model
For the help page of the base R filter function, see filter.
# S3 method for libbi
filter(x, ...)# S3 method for bi_model
filter(x, ...)
an updated libbi object
a libbi or bi_model object, or the name of a file containing the model
options to be passed to run.libbi