Learn R Programming

rbi (version 0.10.4)

find_block: Find a block in a LibBi model

Description

Finds a block and returns the range of line numbers encompassed by that block.

Usage

# S3 method for bi_model
find_block(x, name, inner = FALSE)

Value

an integerr vector, the range of line numbers

Arguments

x

a bi_model object

name

of the block to find

inner

only return the inner part of the block (not the block definition)

See Also

bi_model