This function takes the provided libbi object
which has been run and returns a data frame with the parameter
traces.
get_traces(x, model, burnin, all = FALSE, ...)a model to get the parameter names from; not needed if
'run' is given as a libbi object or 'all' is set
to TRUE
proportion of iterations to discard as burn-in (if between 0 and 1), or number of samples to discard (if >1)
whether all variables in the run file should be considered (otherwise, just parameters)
parameters to bi_read (e.g., dimensions)
data frame with parameter traces; this can be fed to
coda routines