libbi allows to call LibBi.
Upon creating a new libbi object, the following arguments can be given.
Once the instance is created, LibBi can be run through the sample, filter, or optimise, or rewrite
methods. Note that libbi objects can be plotted using plot if the rbi.helpers package is loaded.