Learn R Programming

rbi (version 0.6.0)

log2normw: Normalize log weights

Description

This function takes a vector of real values, then takes the exponential and divides by the sum. Substracting the max of the original values increases the numerical stability.

Usage

log2normw(lw)

Arguments

lw
a vector of real values

Value

a vector of normalized values (summing to 1)