The method optimise launches libbi to optimise the parameters with respect to the likelihood or posterior distribution. See the options to run.libbi for how to specify the various components of sampling with LibBi, and the LibBi manual for all options that can be passed when the client is optimise.
If x is given as a 'bi_model', a libbi object will be created from the model
For the help page of the base R optimise function, see optimise.
# S3 method for libbi
optimise(x, ...)# S3 method for bi_model
optimise(x, ...)
options to be passed to run.libbi
a libbi object