Learn R Programming

rbi (version 0.6.0)

option_list: Convert string to option list

Description

This function is used to convert an option string into a list of options. If a list is given, it will be kept as is

Usage

option_list(...)

Arguments

...
any number of strings to convert

Value

option list