Rdocumentation
powered by
Learn R Programming
rbi (version 0.6.0)
option_string: Convert Options
Description
This function is used to convert a list of options into an options string. If a string is given, it will be taken as such.
Usage
option_string(...)
Arguments
...
any number of lists of options, or strings (which will be left unmodified). If lists are given, later arguments will override earlier ones