powered by
The method predict is an alias for sample(target="prediction"). Usually, an init object or file should be given containing posterior samples.
predict
sample(target="prediction")
init
For the help page of the base R optimise function, see optimise.
optimise
# S3 method for libbi predict(object, ...)
a libbi object
libbi
ignored