Learn R Programming

rbi (version 0.9.1)

propose_prior: Propose from the prior in a libbi model

Description

Generates a version of the model where the proposal blocks are replaced by the prior blocks. This is useful for exploration of the likelihood surface.

Usage

propose_prior(x)

Arguments

x

a bi_model object

Value

a bi model object of the new model

See Also

bi_model