powered by
LibBi
This reads all options, files and outputs of a LibBi run from a specified RDS file or folder (if split = TRUE has been used with save_libbi).
split = TRUE
save_libbi
read_libbi(name, ...)
a new libbi object
libbi
name of the RDS file(s) to read
any extra options to pass to libbi when creating the new object