replace_all: Replace all instances of a string with another in a model
Description
Takes every occurrence of one string and replaces it with another
Usage
# S3 method for bi_model
replace_all(x, from, to, ...)
Arguments
from
string to be replaced (a regular expression)
to
new string (which can refer to the regular expression given as from)
Value
the updated bi model