Learn R Programming

rbi (version 0.7.0)

rewrite: Using the LibBi wrapper to rewrite

Description

The method rewrite launches LibBi to rewrite a model to inspect its internal representation in LibBi

If x is given as a 'bi_model', a libbi object will be created from the model If x is given as a character string, it will be interpreted as the filename of a model to sample from.

Usage

# S3 method for libbi
rewrite(x, ...)

# S3 method for bi_model rewrite(x, ...)

# S3 method for character rewrite(x, ...)

Arguments

x

a libbi or bi_model object, or the name of a file containing the model

...

options to be passed to run.libbi

Value

a bi_model object