The method sample launches libbi to sample from a (prior, posterior or joint) distribution. See the options to run.libbi for how to specify the various components of sampling with LibBi, and the LibBi manual for all options that can be passed when the client is sample.
If x is given as a 'bi_model', a libbi object will be created from the model
If x is given as a character string, it will be interpreted as the filename of a model to sample from.
For the help page of the base R sample function, see sample.
# S3 method for libbi
sample(x, ...)# S3 method for bi_model
sample(x, ...)
# S3 method for character
sample(x, ...)
options to be passed to run.libbi
a libbi object