Learn R Programming

rbi (version 0.9.1)

var_names: Get variables

Description

Get all variable names of one or more type(s)

This returns all variable names of a certain type ("param", "state", "obs", "noise", "const") contained in the model of a libbi object

Usage

# S3 method for bi_model
var_names(x, type, dim = FALSE, opt = FALSE,
  aux = FALSE, ...)

Arguments

x

a bi_model object

type

a character vector of one or more types

dim

logical; if set to TRUE, names will contain dimensions in brackets

opt

logical; if set to TRUE, names will contain options (e.g., has_output)

aux

logical; if set to TRUE, auxiliary names will be returned

...

ignored

Value

variable names