powered by
Extracts a subset of lines from the model and, if used with the assignment operator, assigns new character strings.
# S3 method for bi_model [(x, i, ...) <- value
A bi_model
A vector of line numbers
ignored
A vector of the same length as i, containing the replacement strings
i
# NOT RUN { model_file_name <- system.file(package="rbi", "PZ.bi") PZ <- bi_model(filename = model_file_name) PZ[3:4] PZ[3:4] <- c("const e = 0.4", "const m_l = 0.05") # }
Run the code above in your browser using DataLab