Learn R Programming

rbi (version 0.7.0)

assert_output: Check that a LibBi wrapper has valid output

Description

This checks that the libbi object given has been run (via sample, filter or optimize)) and the output file has not been modified since.

Usage

assert_output(x, ...)

Arguments

x

a libbi object

...

ignored