powered by
This checks that the libbi object given has been run (via sample, filter or optimize)) and the output file has not been modified since.
libbi
sample
filter
optimize
assert_output(x, ...)
a libbi object
ignored