libbi objectDeprecated (use 'attach' instead). Adds an (output, obs, etc.) file to a libbi object. This is useful to recreate a libbi object from the model and output files of a previous run
# S3 method for libbi
attach_file(x, file, data, force = FALSE, ...)an updated libbi object
a libbi object
the type of the file to attach, one of "output", "obs", "input" or "init"
name of the file to attach, or a list of data frames that contain the outputs
attach the file even if one like this already exists in the libbi object
any options to bi_write (e.g., 'time_dim')