Learn R Programming

rbi (version 0.6.0)

bi_contents: Bi contents

Description

This function gets the name of all the variables in the passed file, list or libbi object

Usage

bi_contents(read)

Arguments

read
either a path to a NetCDF file, or a NetCDF connection created using nc_open, or a libbi object from which to read the output

Value

vector of variable names

Examples

Run this code
example_output_file <- system.file(package="rbi", "example_output.nc")
bi_contents(example_output_file)

Run the code above in your browser using DataLab