Learn R Programming

rbi (version 0.9.1)

bi_file_summary: NetCDF File Summary

Description

This function prints a little summary of the content of a NetCDF file, as well as its creation time. You can then retrieve variables of interest using bi_read.

Usage

bi_file_summary(...)

Arguments

...

Any extra parameters to bi_open, especially x and file

Value

None

Examples

Run this code
# NOT RUN {
example_output_file <- system.file(package="rbi", "example_output.nc")
bi_file_summary(example_output_file)
# }

Run the code above in your browser using DataLab