powered by
This function prints a little summary of the content of a NetCDF file, as well as its creation time. You can then retrieve variables of interest using bi_read.
bi_read
bi_file_summary(filename)
A path to a NetCDF file
None