Learn R Programming

rbi (version 0.6.0)

bi_file_summary: NetCDF File Summary

Description

This function prints a little summary of the content of a NetCDF file, as well as its creation time. You can then retrieve variables of interest using bi_read.

Usage

bi_file_summary(filename)

Arguments

filename
path to a NetCDF file

Value

None