This is a wrapper around libbi sample --target joint --nsamples 1, to generate a
synthetic dataset from a model. Parameters can be passed via the 'init' option
(see run.libbi, otherwise they are generated from the prior specified
in the model. The end time should be specified using the "end_time" option. If this is not given,
only a parameter set is sampled.
bi_generate_dataset(..., seed)random seed; see the seed option of sample for details.
generated data set