bi_generate_dataset: Bi Generate Dataset
Description
This is a wrapper around libbi sample --target joint --nsamples 1, to generate a
synthetic dataset from a model. Parameters can be passed via the 'init' option
(see libbi_run, otherwise they are generated from the prior specified
in the model. The end time should be specified using the "end_time" option. If this is not given,
only a parameter set is sampled.
Usage
bi_generate_dataset(...)
Arguments
...
arguments to be passed to libbi (with run = TRUE), especially 'end_time'