Learn R Programming

rbi (version 0.7.0)

bi_model: Bi Model

Description

bi_model creates a model object for Rbi from a libbi file, URL or character vector. Once the instance is created, the model can be fed to a libbi object.

Usage

bi_model(filename, lines, ...)

Arguments

filename

the file name of the model file

lines

lines of the model (if no filename is given), a character vector

...

ignored

See Also

fix, insert_lines, remove_lines, replace_all, get_name, set_name, write_file

Examples

Run this code
# NOT RUN {
model_file_name <- system.file(package="rbi", "PZ.bi")
PZ <- bi_model(filename = model_file_name)
# }

Run the code above in your browser using DataLab