Learn R Programming

rbi (version 0.7.0)

bi_open: Bi open

Description

This function opens an NetCDF file The file can be specified as a string to the filepath, in which case a NetCDF connection is opened, or directly as a NetCDF connection.

Usage

bi_open(x)

Arguments

x

either a path to a NetCDF file, or a NetCDF connection created using nc_open, or a libbi object from which to read the output

Value

open NetCDF connection