LibBi run.This function takes the provided libbi
object which has been run and extracts a data frame.
traces.
extract_sample(x, np, ...)iteration to extract; if not given a random sample will be extracted
parameters to bi_read (e.g., dimensions)
list of parameters and trajectories