Learn R Programming

rbi (version 0.9.1)

get_block: Get the contents of a block in a LibBi model

Description

Returns the contents of a block in a LibBi model as a character vector of lines.

Usage

# S3 method for bi_model
get_block(x, name, ...)

Arguments

x

a bi_model object

name

name of the block

...

ignored

Value

a character vector of the lines in the block