get_block: Get the contents of a block in a LibBi model
Description
Returns the contents of a block in a LibBi model as a character vector of
lines.
Usage
# S3 method for bi_model
get_block(x, name, ...)
Value
a character vector of the lines in the block