This function takes the provided libbi
which has been run and returns a data frame with the parameter
traces.
Usage
get_traces(run, model, burnin, all = FALSE, ...)
Arguments
run
a libbi object which has been run, or a
list of data frames containing parameter traces (as returned by
from bi_read); if it is not a libbi
object, either 'all' must be TRUE or a model given
model
a model to get the parameter names from; not needed if
'run' is given as a libbi object or 'all' is set
to TRUE
burnin
proportion of iterations to discard as burn-in
all
whether all variables in the run file should be
considered (otherwise, just parameters)
...
parameters to bi_read (e.g., dimensions)
Value
data frame with parameter traces; this can be fed to
coda routines