libbi allows to call LibBi.
Upon creating a new libbi object, the following arguments can be given.
Once the instance is created, LibBi can be run through the sample, filter, or optimise, or rewrite
methods. Note that libbi objects can be plotted using plot if the rbi.helpers package is loaded.
either a character vector giving the path to a model file (typically ending in ".bi"), or a bi_model object
path_to_libbi
path to LibBi binary; by default it tries to locate the libbi binary
using the which Unix command, after having loaded "~/.bashrc" if present;
if unsuccessful it tries "~/PathToBiBin/libbi"; if unsuccessful again it fails.
dims
any named dimensions, as list of character vectors