Internal function that creates a NetCDF file given a list.
netcdf_create_from_list(filename, variables, time_dim, coord_dims, dim_factors,
value_column = "value", guess_time = FALSE, guess_coord = FALSE,
verbose)a path to a NetCDF file to write the variable into, which will be overwritten if it already exists.
a list
the name of the time dimension, if one exists; default: "time"
the names of the coordinate dimension, if any; should be a named list of character vectors, they are matched to variables names
factors that dimensions have; this corresponds to the dims element of a libbi object
if any variables are data frames, which column contains the values (default: "value")
whether to guess time dimension; this would be a numerical column in the data frame given which is not the value_column; only one such column must exist
whether to guess the coordinate dimension; this would be a column with varying value which is not the time or value column
if TRUE, will print variables as they are read
A list of the time and coord dims, and factors in extra dimensions, if any
The list of variables must follow the following rules. Each element of the list must itself be one of:
1) a data frame with a value_column column (see option 'value_column') and any number of other
columns indicating one or more dimensions
2) a numeric vector of length one, with no dimensions
The name of the list elements itself is used to create the corresponding variable in the NetCDF file.