Learn R Programming

rbi (version 0.7.0)

optimise: Using the LibBi wrapper to optimise

Description

The method optimise launches libbi to optimise the parameters with respect to the likelihood or posterior distribution. See the options to run.libbi for how to specify the various components of sampling with LibBi, and the LibBi manual for all options that can be passed when the client is optimise.

If x is given as a 'bi_model', a libbi object will be created from the model If x is given as a character string, it will be interpreted as the filename of a model to sample from.

For the help page of the base R optimise function, see optimise.

Usage

# S3 method for libbi
optimise(x, ...)

# S3 method for bi_model optimise(x, ...)

# S3 method for character optimise(x, ...)

Arguments

x

a libbi or bi_model object, or the name of a file containing the model

...

options to be passed to run.libbi

Value

a libbi object