Learn R Programming

rbi (version 0.7.0)

predict: Using the LibBi wrapper to predict

Description

The method predict is an alias for sample(target="prediction"). Usually, an init object or file should be given containing posterior samples.

For the help page of the base R optimise function, see optimise.

Usage

# S3 method for libbi
predict(object, ...)

Arguments

object

a libbi object

...

ignored