powered by
Generates a version of the model where the proposal blocks are replaced by the prior blocks. This is useful for exploration of the likelihood surface.
propose_prior(x)
a bi_model object
bi_model
a bi model object of the new model