The package includes a wrapper for the libbi script, allowing
to launch the libbi command from within R.
It also provides various utility functions to browse the output from libbi,
for instance to plot the results.
The package is made of various components:
A wrapper around libbi called libbi.
A bi_model class that can be used to load and manipulate libbi models
Functions to manipulate the results of the libbi command,
which are stored in NetCDF files. Those functions allow to extract variables of
interest.