Learn R Programming

rbi (version 0.7.0)

rbi-package: RBi - R interface for libbi

Description

rbi is an interface to libbi, a library for Bayesian Inference

Arguments

Details

The package includes a wrapper for the libbi script, allowing to launch the libbi command from within R. It also provides various utility functions to browse the output from libbi, for instance to plot the results.

The package is made of various components:

  • A wrapper around libbi called libbi.

  • A bi_model class that can be used to load and manipulate libbi models

  • Functions to manipulate the results of the libbi command, which are stored in NetCDF files. Those functions allow to extract variables of interest.

References

http://libbi.org/

See Also

libbi

Examples

Run this code
# NOT RUN {
example_output_file <- system.file(package="rbi", "example_output.nc")
bi_file_summary(example_output_file)
mu_sigma <- bi_read(example_output_file, c("mu", "sigma"))
bi_write("mu_sigma.nc", mu_sigma)

## examples for running libbi from rbi (will take a few minutes)
# }
# NOT RUN {
demo(PZ_generate_dataset)
# }
# NOT RUN {
demo(PZ_PMMH)
# }
# NOT RUN {
demo(PZ_SMC2)
# }
# NOT RUN {
demo(PZ_filtering)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab