Learn R Programming

rbi (version 0.9.1)

remove_lines: Remove line(s) and/or block(s) in a libbi model

Description

Removes one or more lines in a libbi model.

Usage

# S3 method for bi_model
remove_lines(x, what, only, ...)

Arguments

x

a bi_model object

what

either a vector of line number(s) to remove, or a vector of blocks to remove (e.g., "parameter")

only

only remove lines assigning given names (as a vector of character strings)

...

ignored

Value

the updated bi model

See Also

bi_model

Examples

Run this code
# NOT RUN {
model_file_name <- system.file(package="rbi", "PZ.bi")
PZ <- bi_model(filename = model_file_name)
PZ <- remove_lines(PZ, 2)
# }

Run the code above in your browser using DataLab