Learn R Programming

rbi (version 0.7.0)

replace_all: Replace all instances of a string with another in a model

Description

Takes every occurrence of one string and replaces it with another

Usage

# S3 method for bi_model
replace_all(x, from, to, ...)

Arguments

x

a bi_model object

from

string to be replaced (a regular expression)

to

new string (which can refer to the regular expression given as from)

...

ignored

Value

the updated bi model

See Also

bi_model