Get all variable names of one or more type(s)
This returns all variable names of a certain type ("param", "state", "obs", "noise", "const") contained in the model of a libbi object
# S3 method for bi_model
var_names(x, type, dim = FALSE, opt = FALSE,
aux = FALSE, ...)a bi_model object
a character vector of one or more types
logical; if set to TRUE, names will contain dimensions in brackets
logical; if set to TRUE, names will contain options (e.g., has_output)
logical; if set to TRUE, auxiliary names will be returned
ignored
variable names